﻿#define ARCTION_V7
//#define ARCTION_V6

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

#if ARCTION_V7
using Arction.WinForms.Charting;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;
#else
using Arction.LightningChartUltimate;
using Arction.LightningChartUltimate.SeriesXY;
using Arction.LightningChartUltimate.Views.ViewXY;
#endif

namespace AL_IntensityGrid_Logarithmic
{
    public partial class Form1 : Form
    {
        #region Konstanten

        const int COLUMNS = 1400;
        const int ROWS = 1400;

        #endregion
        #region Membervariablen

        private LightningChartUltimate _lcu;
        ViewXY _view;
        private IntensityGridSeries _series;
        private double[][] _data;

        #endregion

        #region Constructor

        public Form1()
        {
            InitializeComponent();

            GenerateData();
            CreateChart();
            CreateSeries();
        }

        #endregion

        #region GenerateData()

        private void GenerateData()
        {
            var random = new Random();

            _data = new double[COLUMNS][];
            for (int x = 0; x < COLUMNS; x++)
            {
                var colData = new double[ROWS];
                for (int y = 0; y < ROWS; y++)
                    colData[y] = 40 * ((double)x / COLUMNS) + 10 * ((double)y / ROWS) + 28.0 * random.NextDouble();
                _data[x] = colData;
            }
        }

        #endregion

        #region CreateChart()

        private void CreateChart()
        {
            _lcu = new LightningChartUltimate();
            //_lcu.RenderOptions.DeviceType = RendererDeviceType.HardwareOnlyD11;
            _lcu.Dock = DockStyle.Fill;
            _lcu.ColorTheme = ColorTheme.LightGray;
            _lcu.Title.Visible = false;

            _lcu.ActiveView = ActiveView.ViewXY;
            _view = _lcu.ViewXY;
            _view.LegendBox.Visible = false;
            _view.XAxes[0].ValueType = AxisValueType.Number;
            _view.XAxes[0].Title.Visible = false;
            _view.YAxes[0].ValueType = AxisValueType.Number;
            _view.YAxes[0].Title.Visible = false;
            _view.YAxes[0].ScaleType = ScaleType.Logarithmic;

            this.Controls.Add(_lcu);
        }

        #endregion
        #region CreateSeries()

        private void CreateSeries()
        {
            _lcu.BeginUpdate();

            var axisX = _view.XAxes[0];
            var axisY = _view.YAxes[0];

            _series = new IntensityGridSeries(_view, axisX, axisY)
            {
                //PixelRendering = true,
                MouseInteraction = false,
            };
            //_series.ValueRangePalette = CreatePalette(_series, 0, 3);
            const double k = 10;
            _series.SetRangesXY(-k, k, -k, k);
            _series.SetSize(COLUMNS, ROWS);

            _series.SetValuesData(_data, IntensityGridValuesDataOrder.ColumnsRows);
            _series.InvalidateValuesDataOnly();

            axisX.SetRange(-k, k);
            axisY.SetRange(-k, k);

            _view.IntensityGridSeries.Add(_series);

            _lcu.EndUpdate();
        }

        #endregion
        #region RemoveChart()

        private void RemoveChart()
        {
            if (_series != null)
                RemoveSeries();

            this.Controls.Remove(_lcu);
            _lcu.Dispose();
            _lcu = null;
            _view = null;

            GC.Collect();
        }

        #endregion
        #region RemoveSeries()

        private void RemoveSeries()
        {
            _view.IntensityGridSeries.Clear();
            _series = null;
        }

        #endregion
    }
}
